%{?scl:%scl_package okhttp}
%{!?scl:%global pkg_name %{name}}

%global baserelease 1

%bcond_without okcurl

Name:           %{?scl_prefix}okhttp
Version:        3.10.0
Release:        5.%{baserelease}%{?dist}
Summary:        An HTTP+HTTP/2 client for Java applications

License:        ASL 2.0
URL:            http://square.github.io/%{pkg_name}/
Source0:        https://github.com/square/%{pkg_name}/archive/parent-%{version}.tar.gz

# Patch out platform support for platforms not available in Fedora
Patch0:         okhttp-rm-android-conscrypt.patch

BuildArch:      noarch

BuildRequires:  %{?scl_prefix_maven}maven-local
BuildRequires:  %{?scl_prefix_maven}mvn(com.google.code.findbugs:jsr305)
BuildRequires:  %{?scl_prefix}mvn(com.squareup.okio:okio) >= 1.14.0
BuildRequires:  %{?scl_prefix_maven}mvn(junit:junit)
BuildRequires:  %{?scl_prefix_maven}mvn(org.apache.httpcomponents:httpclient)
BuildRequires:  %{?scl_prefix_maven}mvn(org.apache.maven.surefire:surefire-junit47)
BuildRequires:  %{?scl_prefix_maven}mvn(org.sonatype.oss:oss-parent:pom:)
%if %{with okcurl}
BuildRequires:  %{?scl_prefix_maven}mvn(com.google.guava:guava)
BuildRequires:  mvn(io.airlift:airline)
BuildRequires:  %{?scl_prefix}mvn(org.bouncycastle:bcprov-jdk15on)
%endif

Requires:  %{?scl_prefix}mvn(com.squareup.okio:okio) >= 1.14.0

# No longer able to build samples
Obsoletes: %{name}-samples < %{version}
Provides:  %{name}-samples = %{version}-%{release}
Obsoletes: %{name}-samples-guide < %{version}
Provides:  %{name}-samples-guide = %{version}-%{release}
Obsoletes: %{name}-samples-simple-client < %{version}
Provides:  %{name}-samples-simple-client = %{version}-%{release}

# Websocket modules were merged into main artifact
Obsoletes: %{name}-ws < %{version}
Provides:  %{name}-ws = %{version}-%{release}
Obsoletes: %{name}-ws-tests < %{version}
Provides:  %{name}-ws-tests = %{version}-%{release}

%description
An HTTP & HTTP/2 client for Android and Java applications.

%package javadoc
Summary:        Javadoc for %{pkg_name}

%description javadoc
API documentation for %{pkg_name}.

%package parent
Summary:        Parent POM for OkHttp

%description parent
%{summary}.

%package apache
Summary:        OkHttp Apache HttpClient

%description apache
%{summary}.

%package urlconnection
Summary:        OkHttp URLConnection

%description urlconnection
%{summary}.

%if %{with okcurl}

%package okcurl
Summary:        A curl for the next-generation web

%description okcurl
OkCurl is an OkHttp-backed curl clone which
allows you to test OkHttp\'s HTTP engine
(including SPDY and HTTP/2) against web servers.
%endif

%package logging-interceptor
Summary:        OkHttp Logging Interceptor

%description logging-interceptor
%{summary}.

%package testing-support
Summary:        OkHttp test support classes

%description testing-support
%{summary}.


%prep
%{?scl:scl enable %{scl_maven} %{scl} - << "EOFSCL"}
set -e -x
%setup -q -n %{pkg_name}-parent-%{version}

# Don't need animal sniffer for RPM build
%pom_remove_plugin org.codehaus.mojo:animal-sniffer-maven-plugin
%pom_remove_dep :animal-sniffer-annotations okhttp-urlconnection
sed -i -e '/IgnoreJRERequirement/d' okhttp-urlconnection/src/main/java/okhttp3/internal/huc/DelegatingHttpsURLConnection.java

# templating-maven-plugin is not available in Fedora. Filter sources
# manually before build.
%pom_remove_plugin :templating-maven-plugin okhttp
sed 's|\${project.version}|%{version}|' okhttp/src/main/java-templates/okhttp3/internal/Version.java >okhttp/src/main/java/okhttp3/internal/Version.java

# Missing deps: com.google.caliper, moshi
%pom_disable_module mockwebserver
%pom_disable_module benchmarks
%pom_disable_module samples
%pom_disable_module okhttp-tests

%if %{without okcurl}
%pom_disable_module okcurl
%endif

# Unneeded plugins for RPM build
%pom_remove_plugin :maven-assembly-plugin okcurl
%pom_remove_plugin :maven-checkstyle-plugin
%pom_remove_plugin :maven-release-plugin

# Errorprone not available in Fedora
%pom_remove_dep org.codehaus.plexus:plexus-compiler-javac-errorprone
%pom_remove_dep com.google.errorprone:error_prone_core
sed -i -e '/javac-with-errorprone/d' pom.xml

# Unavailable plugin
%pom_remove_plugin org.skife.maven:really-executable-jar-maven-plugin okcurl
# Fix main class
%pom_add_plugin "org.apache.maven.plugins:maven-jar-plugin:2.4" okcurl "
<configuration>
  <archive>
    <manifest>
      <mainClass>okhttp3.curl.Main</mainClass>
    </manifest>
  </archive>
</configuration>"

# Remove support for android and conscrypt, not in Fedora
%patch0
%pom_disable_module okhttp-android-support
%pom_remove_dep com.google.android:android okhttp
%pom_remove_dep org.conscrypt:conscrypt-openjdk-uber okhttp

# For compatibility
%mvn_alias com.squareup.okhttp3:okhttp com.squareup.okhttp:okhttp com.squareup.okhttp3:okhttp-ws com.squareup.okhttp:okhttp-ws
%{?scl:EOFSCL}

%build
%{?scl:scl enable %{scl_maven} %{scl} - << "EOFSCL"}
set -e -x
# We don't have all test deps (e.g. npn-boot)
%mvn_build -s --skip-tests -- -P !alpn-when-jdk8

%{?scl:EOFSCL}

%install
%{?scl:scl enable %{scl_maven} %{scl} - << "EOFSCL"}
set -e -x
%mvn_install

%{?scl:EOFSCL}

%files -f .mfiles-%{pkg_name}
%doc CHANGELOG.md README.md
%license LICENSE.txt

%files javadoc -f .mfiles-javadoc
%license LICENSE.txt

%files parent -f .mfiles-parent
%license LICENSE.txt

%files apache -f .mfiles-okhttp-apache

%files urlconnection -f .mfiles-okhttp-urlconnection

%if %{with okcurl}

%files okcurl -f .mfiles-okcurl
%endif

%files logging-interceptor -f .mfiles-logging-interceptor

%files testing-support -f .mfiles-okhttp-testing-support


%changelog
* Tue Mar 05 2019 Mat Booth <mat.booth@redhat.com> - 3.10.0-5.1
- Auto SCL-ise package for rh-eclipse collection

* Fri Feb 01 2019 Fedora Release Engineering <releng@fedoraproject.org> - 3.10.0-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Fri Jul 13 2018 Fedora Release Engineering <releng@fedoraproject.org> - 3.10.0-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Wed Mar 21 2018 Mat Booth <mat.booth@redhat.com> - 3.10.0-3
- Tighten requirement on okio

* Tue Mar 20 2018 Mat Booth <mat.booth@redhat.com> - 3.10.0-2
- Add compatibility maven coords

* Tue Mar 20 2018 Mat Booth <mat.booth@redhat.com> - 3.10.0-1
- Update to latest release
- No longer able to build sample projects
- Websocket modules were merged into main artifact
- Enable urlconnection module

* Thu Feb 08 2018 Fedora Release Engineering <releng@fedoraproject.org> - 2.7.4-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Wed Dec 06 2017 Mat Booth <mat.booth@redhat.com> - 2.7.4-5
- Update BRs

* Wed Dec 06 2017 Mat Booth <mat.booth@redhat.com> - 2.7.4-4
- Conditionally build curl module
- Remove unnecessary checkstyle invocation
- Fix FTBFS

* Thu Jul 27 2017 Fedora Release Engineering <releng@fedoraproject.org> - 2.7.4-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Sat Feb 11 2017 Fedora Release Engineering <releng@fedoraproject.org> - 2.7.4-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Tue Feb 16 2016 Gerard Ryan <galileo@fedoraproject.org> - 2.7.4-1
- Update to version 2.7.4 for RHBZ 1308853

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 2.2.0-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Sun Aug 16 2015 gil cattaneo <puntogil@libero.it> 2.2.0-5
- enable okcurl module
- introduce license macro

* Thu Jun 18 2015 Mat Booth <mat.booth@redhat.com> - 2.2.0-4
- Add missing BR to fix FTBFS

* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.2.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Thu Mar 12 2015 Mikolaj Izdebski <mizdebsk@redhat.com> - 2.2.0-2
- Add obsoletes for {name}-protocols

* Wed Mar 11 2015 Mikolaj Izdebski <mizdebsk@redhat.com> - 2.2.0-1
- Update to upstream version 2.2.0

* Thu Sep 25 2014 Mikolaj Izdebski <mizdebsk@redhat.com> - 2.0.0-1
- Update to upstream version 2.0.0

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.2.1-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Tue Mar 04 2014 Stanislav Ochotnicky <sochotnicky@redhat.com> - 1.2.1-2
- Use Requires: java-headless rebuild (#1067528)

* Sat Nov 23 2013 Gerard Ryan <galileo@fedoraproject.org> - 1.2.1-1
- Initial rpm